==> mars-policy-2.2.1.10-Release-sources.jar: com/bizunited/platform/mars/policy/process/cache/RuntimeNodeNexts.java <==
package com.bizunited.platform.mars.policy.process.cache;

/**
 * 规则引擎中的连线信息
 * @author yinwenjie
 */
public class RuntimeNodeNexts {
  /**
   * 对应的存储层连线的id信息
   */
  private String id;
  /**
   * 该连接线对应的节点信息（目标节点编号）
   * 该节点一定引用至对应的RuntimeDefinition对象中的某一个RuntimeNode对象的id
   */
  private String toNodeCode;
  /**
   * 如果当前处理节点有多个连续线
   * 则连接线的判定顺序以当前设定值为准（值越小优先级越高）
   */
  private Integer sort = 100;
  /**
   * 有一些场景满足过滤条件的集合中的一组数据是要放入到一个新的集合存储到上下文中的
   * 该参数指定这个集合的变量名
   */
  private String bindParam;
  /**
   * 线条类型(1：正常线；2：异常线)
   */
  private Integer lineType;
  /**
   * 流转表达式（流转条件）
   */
  private String conditions;
  /**
   * 异常线支持的完整异常类型（多个使用“,”分割）
   */
  private String exceptions;
  public String getToNodeCode() {
    return toNodeCode;
  }
  public void setToNodeCode(String toNodeCode) {
    this.toNodeCode = toNodeCode;
  }
  public Integer getSort() {
    return sort;
  }
  public void setSort(Integer sort) {
    this.sort = sort;
  }
  public Integer getLineType() {
    return lineType;
  }
  public void setLineType(Integer lineType) {
    this.lineType = lineType;
  }
  public String getConditions() {
    return conditions;
  }
  public void setConditions(String conditions) {
    this.conditions = conditions;
  }
  public String getExceptions() {
    return exceptions;
  }
  public void setExceptions(String exceptions) {
    this.exceptions = exceptions;
  }
  public String getId() {
    return id;
  }
  public void setId(String id) {
    this.id = id;
  }
  public String getBindParam() {
    return bindParam;
  }
  public void setBindParam(String bindParam) {
    this.bindParam = bindParam;
  }
}

==> mars-policy-2.2.1.12-Release-sources.jar: com/bizunited/platform/mars/policy/process/cache/RuntimeNodeNexts.java <==
package com.bizunited.platform.mars.policy.process.cache;

/**
 * 规则引擎中的连线信息
 * @author yinwenjie
 */
public class RuntimeNodeNexts {
  /**
   * 对应的存储层连线的id信息
   */
  private String id;
  /**
   * 该连接线对应的节点信息（目标节点编号）
   * 该节点一定引用至对应的RuntimeDefinition对象中的某一个RuntimeNode对象的id
   */
  private String toNodeCode;
  /**
   * 如果当前处理节点有多个连续线
   * 则连接线的判定顺序以当前设定值为准（值越小优先级越高）
   */
  private Integer sort = 100;
  /**
   * 有一些场景满足过滤条件的集合中的一组数据是要放入到一个新的集合存储到上下文中的
   * 该参数指定这个集合的变量名
   */
  private String bindParam;
  /**
   * 线条类型(1：正常线；2：异常线)
   */
  private Integer lineType;
  /**
   * 流转表达式（流转条件）
   */
  private String conditions;
  /**
   * 异常线支持的完整异常类型（多个使用“,”分割）
   */
  private String exceptions;
  /**
   * 连线描述
   */
  private String nextDesc;

  public String getToNodeCode() {
    return toNodeCode;
  }
  public void setToNodeCode(String toNodeCode) {
    this.toNodeCode = toNodeCode;
  }
  public Integer getSort() {
    return sort;
  }
  public void setSort(Integer sort) {
    this.sort = sort;
  }
  public Integer getLineType() {
    return lineType;
  }
  public void setLineType(Integer lineType) {
    this.lineType = lineType;
  }
  public String getConditions() {
    return conditions;
  }
  public void setConditions(String conditions) {
    this.conditions = conditions;
  }
  public String getExceptions() {
    return exceptions;
  }
  public void setExceptions(String exceptions) {
    this.exceptions = exceptions;
  }
  public String getId() {
    return id;
  }
  public void setId(String id) {
    this.id = id;
  }
  public String getBindParam() {
    return bindParam;
  }
  public void setBindParam(String bindParam) {
    this.bindParam = bindParam;
  }
  public String getNextDesc() {
    return nextDesc;
  }
  public void setNextDesc(String nextDesc) {
    this.nextDesc = nextDesc;
  }
}
